<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="cantor_part" version="2">
<MenuBar>
  <Menu name="file">
    <Action name="file_save"/>
    <Action name="file_save_as"/>
    <Action name="file_save_plain"/>
    <Action name="file_export_latex"/>
    <Action name="file_publish_worksheet"/>
    <Separator/>
    <Action name="file_print"/>
    <Action name="file_print_preview"/>
  </Menu>
  <Menu name="edit"><text>&amp;Edit</text>
    <Action name="edit_undo"/>
    <Action name="edit_redo"/>
    <Separator/>
    <Action name="edit_cut"/>
    <Action name="edit_copy"/>
    <Action name="edit_paste"/>
    <Separator/>
    <Action name="edit_find"/>
    <Action name="edit_replace"/>
    <Action name="edit_find_next"/>
    <Action name="edit_find_prev"/>
  </Menu>
  <Menu name="view"><text>&amp;View</text>
    <Action name="view_zoom_in"/>
    <Action name="view_zoom_out"/>
    <Action name="show_editor"/>
  </Menu>
  <Menu name="worksheet"><text>&amp;Worksheet</text>
    <Action name="evaluate_worksheet"/>
    <Action name="evaluate_current"/>
    <Action name="insert_command_entry"/>
    <Action name="insert_text_entry"/>
    <Action name="insert_latex_entry"/>
    <Action name="insert_image"/>
    <Action name="insert_page_break_entry"/>
    <Action name="remove_current"/>
  </Menu>
  <Menu name="settings">
    <Action name="enable_typesetting"/>
    <Action name="enable_highlighting"/>
    <Action name="enable_completion"/>
    <Action name="enable_expression_numbers"/>
    <Action name="enable_animations"/>
  </Menu>
  <Menu name="help">
    <Action name="backend_help"/>
  </Menu>
  <Merge/>
</MenuBar>
<ToolBar name="mainToolBar">
  <Action name="file_new"/>
  <Action name="file_open"/>
  <Action name="file_save"/>
  <Action name="file_print"/>
  <Action name="file_print_preview"/>
  <Action name="edit_find"/>
  <Action name="evaluate_worksheet"/>
  <Action name="restart_backend"/>
  <Action name="backend_help"/>
  <Separator/>
</ToolBar>
<ToolBar noMerge="1" name="textEditToolBar">
  <Separator/>
  <Action name="format_text_bold"/>
  <Action name="format_text_italic"/>
  <Action name="format_text_underline"/>
  <Action name="format_text_strikeout"/>
  <Action name="format_text_foreground_color"/>
  <Action name="format_text_background_color"/>
  <Separator/>
  <Action name="format_font_family"/>
  <Action name="format_font_size"/>
  <Separator/>
  <Action name="format_align_left"/>
  <Action name="format_align_center"/>
  <Action name="format_align_right"/>
  <Action name="format_align_justify"/>
  <Action name="format_list_style"/>
  <Action name="format_list_indent_more"/>
  <Action name="format_list_indent_less"/>
  <Separator/>
</ToolBar>
</kpartgui>
